@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from collections.abc import Callable
 from contextlib import AsyncExitStack, asynccontextmanager
 from fnmatch import fnmatch
 from importlib import resources
@@ -20,7 +21,7 @@ import structlog
 
 from bowtie import _report
 from bowtie._commands import Test, TestCase
-from bowtie._core import GotStderr, Implementation, StartupFailed
+from bowtie._core import GotStderr, Implementation, NoSuchImage, StartupFailed
 from bowtie.exceptions import _ProtocolError
 
 IMAGE_REPOSITORY = "ghcr.io/bowtie-json-schema"
@@ -217,6 +218,7 @@ def run(context, input, filter, **kwargs):
 @IMPLEMENTATION
 @DIALECT
 @SET_SCHEMA
+@VALIDATE
 @click.argument("schema", type=click.File(mode="rb"))
 @click.argument("instances", nargs=-1, type=click.File(mode="rb"))
 def validate(context, schema, instances, **kwargs):
@@ -231,8 +233,7 @@ def validate(context, schema, instances, **kwargs):
             for i, instance in enumerate(instances, 1)
         ],
     )
-    kwargs.update(fail_fast=False, make_validator=do_not_validate)
-    exit_code = asyncio.run(_run(**kwargs, cases=[case]))
+    exit_code = asyncio.run(_run(fail_fast=False, **kwargs, cases=[case]))
     context.exit(exit_code)
 
 
@@ -255,7 +256,15 @@ async def _smoke(image_names: list[str]):
         reporter=None,  # FIXME: we don't want to print anything here
     ) as starting:
         for each in asyncio.as_completed(starting):
-            implementation = await each
+            try:
+                implementation = await each
+            except NoSuchImage as error:
+                exit_code |= os.EX_CONFIG
+                click.echo(
+                    f"❗ (error): {error.name!r} is not a known Bowtie implementation.",  # noqa: E501
+                )
+                continue
+
             click.echo(f"Testing {implementation.name!r}...")
 
             if implementation.metadata is None:
@@ -315,7 +324,7 @@ class _TestSuiteCases(click.ParamType):
         if is_local_path:
             cases, dialect = self._cases_and_dialect(path=Path(value))
         else:
-            from github3 import GitHub
+            from github3 import GitHub  # type: ignore
 
             gh = GitHub()
             repo = gh.repository("json-schema-org", "JSON-Schema-Test-Suite")
@@ -394,7 +403,7 @@ async def _run(
     dialect: str,
     fail_fast: bool,
     set_schema: bool,
-    make_validator: callable,
+    make_validator: Callable,
     reporter: _report.Reporter = _report.Reporter(),
 ):
     acknowledged, runners, exit_code = [], [], 0
@@ -411,6 +420,10 @@ async def _run(
                 exit_code = os.EX_CONFIG
                 reporter.startup_failed(name=error.name)
                 continue
+            except NoSuchImage as error:
+                exit_code = os.EX_CONFIG
+                reporter.no_such_image(name=error.name)
+                continue
 
             try:
                 if dialect in implementation.dialects:
