@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from collections import deque
+from collections.abc import Callable
 from contextlib import asynccontextmanager
 import asyncio
 import json
@@ -23,6 +24,12 @@ class StartupFailed(Exception):
     name: str
 
 
+@frozen
+class NoSuchImage(Exception):
+
+    name: str
+
+
 class StreamClosed(Exception):
     pass
 
@@ -89,7 +96,7 @@ class DialectRunner:
 
     _name: str
     _dialect: str
-    _send: callable
+    _send: Callable
     _start_response: _commands.StartedDialect
 
     @classmethod
@@ -134,8 +141,8 @@ class Implementation:
 
     name: str
 
-    _make_validator: callable
-    _maybe_validate: callable
+    _make_validator: Callable
+    _maybe_validate: Callable
     _reporter: object
 
     _docker: aiodocker.Docker = field(repr=False)
@@ -163,7 +170,12 @@ class Implementation:
 
         try:
             await self._start_container()
-        except (aiodocker.exceptions.DockerError, StreamClosed):
+        except StreamClosed:
+            raise StartupFailed(name=image_name)
+        except aiodocker.exceptions.DockerError as error:
+            status, data, *_ = error.args
+            if data.get("cause") == "image not known" or status == 500:  # :/
+                raise NoSuchImage(name=image_name)
             raise StartupFailed(name=image_name)
 
         yield self
