@@ -25,7 +25,7 @@ def session(default=True, **kwargs):
 @session(python=["3.8", "3.9", "3.10", "3.11"])
 def tests(session):
     session.install("-r", str(ROOT / "test-requirements.txt"))
-    session.run("pytest")
+    session.run("pytest", "--verbosity=3")
 
 
 @session(tags=["build"])
@@ -78,6 +78,12 @@ def style(session):
     session.run("python", "-m", "flake8", str(BOWTIE), str(TESTS), __file__)
 
 
+@session()
+def typing(session):
+    session.install("mypy", "types-jsonschema", str(ROOT))
+    session.run("python", "-m", "mypy", str(BOWTIE))
+
+
 @session(tags=["docs"])
 @nox.parametrize(
     "builder",
